==> glibc-2.38-loong64-2.txz: install/doinst.sh <==
#!/bin/sh
# Copyright (C) 2002, 2005  Slackware Linux, Inc.
# Copyright 2005, 2006, 2007, 2011, 2012, 2018  Patrick J. Volkerding, Sebeka, Minnesota, USA
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# Swap glibc on the fly.
#
# If we're on a running system we have to handle this _very_ carefully.  :-)
# The tricks involved here get trickier every time...

# OK, now we have to be sure of a few things.  First, you do have a 2.6
# kernel running, right?

if [ -r /proc/ksyms ]; then
  echo "FATAL: you need to be running a 2.6.x kernel in order to upgrade"
  echo "to this version of glibc."
  echo
  sleep 999
  exit 1
fi

# Next, stop using the /lib64/ntpl libraries.  These are now obsolete and
# will break the installation if present:
if [ -d lib64/tls ]; then
  mkdir -p lib64/obsolete
  mv lib64/tls lib64/obsolete
fi
if [ -x sbin/ldconfig ]; then
  sbin/ldconfig -r . 2> /dev/null
fi

# Install NPTL glibc libraries:
if [ -x /sbin/ldconfig -a -d lib64/incoming ]; then # swap on the fly
  # Try to protect with flock against another installpkg/removepkg running
  # ldconfig while we're doing the on-the-fly install:
  mkdir -p run/lock/pkgtools
  ( flock 9 || exit 11
    # First create copies of the incoming libraries:
    ( cd lib64/incoming
      for file in * ; do
        if [ ! -r ../${file}.incoming ]; then
          cp -a $file ../${file}.incoming
        fi
      done
    )
    # Then switch to them all at once:
    /sbin/ldconfig -l lib64/*.incoming 2> /dev/null
    # Remove old versions of the glibc libraries. If you really don't want to
    # do this for some reason, create a file /etc/glibc-nowipe.
    if [ ! -r etc/glibc-nowipe ]; then
      ( cd lib64
        for INCOMING in incoming/*-* ; do
          LIBPREFIX=$(basename $INCOMING | cut -f 1 -d -)
          for LIBRARY in ${LIBPREFIX}-* ; do
            # Don't remove the library if it ends in .incoming:
            if [ "$(echo $LIBRARY | rev | cut -f 1 -d .)" = "gnimocni" ]; then
              continue
            fi
            # Don't remove symlinks:
            if [ -L $LIBRARY ]; then
              continue
            fi
            rm -f $LIBRARY
          done
        done
      )
    fi
    # Finally, rename them and clean up:
    ( cd lib64
      for file in *.incoming ; do
        rm -f `basename $file .incoming`
        cp -a $file `basename $file .incoming`
        /sbin/ldconfig -l `basename $file .incoming` 2> /dev/null
        rm -f $file
      done
    )
  ) 9> run/lock/pkgtools/ldconfig.lock
else # no ldconfig? This is a broken situation, but we will do what we can:
  ( cd lib64/incoming
    for file in * ; do
      cp -a $file ..
    done
  )
fi
# Now, get rid of the temporary directory:
rm -rf lib64/incoming
# Done installing NPTL glibc libraries.

# Handle config files:
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/nscd.conf.new
config etc/profile.d/glibc.csh.new
config etc/profile.d/glibc.sh.new
# Clearly you already decided this issue.  :-)
rm -f etc/profile.d/glibc.csh.new
rm -f etc/profile.d/glibc.sh.new

# This block below *should* be dead code, but it's probably safer to leave it
# here as a fallback. It no longer has complete coverage of all the links
# that would be needed in /lib${LIBDIRSUFFIX}, but it covers enough that if
# we did fall back on this the machine would boot until it reached the boot
# time call to ldconfig, which would then take care of any missing links.
# In case there's no ldconfig, make the links manually:
if [ ! -x /sbin/ldconfig ]; then
( cd lib64 ; rm -rf libm.so.6 )
( cd lib64 ; ln -sf libm-2.38.so libm.so.6 )
( cd lib64 ; rm -rf libnss_files.so.2 )
( cd lib64 ; ln -sf libnss_files-2.38.so libnss_files.so.2 )
( cd lib64 ; rm -rf libresolv.so.2 )
( cd lib64 ; ln -sf libresolv-2.38.so libresolv.so.2 )
( cd lib64 ; rm -rf libutil.so.1 )
( cd lib64 ; ln -sf libutil-2.38.so libutil.so.1 )
( cd lib64 ; rm -rf libnss_compat.so.2 )
( cd lib64 ; ln -sf libnss_compat-2.38.so libnss_compat.so.2 )
( cd lib64 ; rm -rf libthread_db.so.1 )
( cd lib64 ; ln -sf libthread_db-1.0.so libthread_db.so.1 )
( cd lib64 ; rm -rf libnss_hesiod.so.2 )
( cd lib64 ; ln -sf libnss_hesiod-2.38.so libnss_hesiod.so.2 )
( cd lib64 ; rm -rf libanl.so.1 )
( cd lib64 ; ln -sf libanl-2.38.so libanl.so.1 )
( cd lib64 ; rm -rf libcrypt.so.1 )
( cd lib64 ; ln -sf libcrypt-2.38.so libcrypt.so.1 )
( cd lib64 ; rm -rf libBrokenLocale.so.1 )
( cd lib64 ; ln -sf libBrokenLocale-2.38.so libBrokenLocale.so.1 )
( cd lib64 ; rm -rf ld-linux-loongarch-lp64d.so.1 )
( cd lib64 ; ln -sf ld-2.38.so ld-linux-loongarch-lp64d.so.1 )
( cd lib64 ; rm -rf libdl.so.2 )
( cd lib64 ; ln -sf libdl-2.38.so libdl.so.2 )
( cd lib64 ; rm -rf libnss_dns.so.2 )
( cd lib64 ; ln -sf libnss_dns-2.38.so libnss_dns.so.2 )
( cd lib64 ; rm -rf libpthread.so.0 )
( cd lib64 ; ln -sf libpthread-2.38.so libpthread.so.0 )
( cd lib64 ; rm -rf libc.so.6 )
( cd lib64 ; ln -sf libc-2.38.so libc.so.6 )
( cd lib64 ; rm -rf librt.so.1 )
( cd lib64 ; ln -sf librt-2.38.so librt.so.1 )
fi

# More links:
( cd bin ; rm -rf sln )
( cd bin ; ln -sf /sbin/sln sln )
( cd usr/bin ; rm -rf ld.so )
( cd usr/bin ; ln -sf ../../lib64/ld-linux-loongarch-lp64d.so.1 ld.so )
( cd usr/lib64 ; rm -rf libBrokenLocale.so )
( cd usr/lib64 ; ln -sf ../../lib64/libBrokenLocale.so.1 libBrokenLocale.so )
( cd usr/lib64 ; rm -rf libc_malloc_debug.so )
( cd usr/lib64 ; ln -sf ../../lib64/libc_malloc_debug.so.0 libc_malloc_debug.so )
( cd usr/lib64 ; rm -rf libcrypt.so )
( cd usr/lib64 ; ln -sf ../../lib64/libcrypt.so.1 libcrypt.so )
( cd usr/lib64 ; rm -rf libm.so )
( cd usr/lib64 ; ln -sf ../../lib64/libm.so.6 libm.so )
( cd usr/lib64 ; rm -rf libnss_compat.so )
( cd usr/lib64 ; ln -sf ../../lib64/libnss_compat.so.2 libnss_compat.so )
( cd usr/lib64 ; rm -rf libnss_db.so )
( cd usr/lib64 ; ln -sf ../../lib64/libnss_db.so.2 libnss_db.so )
( cd usr/lib64 ; rm -rf libnss_hesiod.so )
( cd usr/lib64 ; ln -sf ../../lib64/libnss_hesiod.so.2 libnss_hesiod.so )
( cd usr/lib64 ; rm -rf libresolv.so )
( cd usr/lib64 ; ln -sf ../../lib64/libresolv.so.2 libresolv.so )
( cd usr/lib64 ; rm -rf libthread_db.so )
( cd usr/lib64 ; ln -sf ../../lib64/libthread_db.so.1 libthread_db.so )

==> glibc-2.40-loong64-5.txz: install/doinst.sh <==
#!/bin/sh
# Copyright (C) 2002, 2005  Slackware Linux, Inc.
# Copyright 2005, 2006, 2007, 2011, 2012, 2018  Patrick J. Volkerding, Sebeka, Minnesota, USA
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# Swap glibc on the fly.
#
# If we're on a running system we have to handle this _very_ carefully.  :-)
# The tricks involved here get trickier every time...

# OK, now we have to be sure of a few things.  First, you do have a 2.6
# kernel running, right?

if [ -r /proc/ksyms ]; then
  echo "FATAL: you need to be running a 2.6.x kernel in order to upgrade"
  echo "to this version of glibc."
  echo
  sleep 999
  exit 1
fi

# Next, stop using the /lib64/ntpl libraries.  These are now obsolete and
# will break the installation if present:
if [ -d lib64/tls ]; then
  mkdir -p lib64/obsolete
  mv lib64/tls lib64/obsolete
fi
if [ -x sbin/ldconfig ]; then
  sbin/ldconfig -r . 2> /dev/null
fi

# Install NPTL glibc libraries:
if [ -x /sbin/ldconfig -a -d lib64/incoming ]; then # swap on the fly
  # Try to protect with flock against another installpkg/removepkg running
  # ldconfig while we're doing the on-the-fly install:
  mkdir -p run/lock/pkgtools
  ( flock 9 || exit 11
    # First create copies of the incoming libraries:
    ( cd lib64/incoming
      for file in * ; do
        if [ ! -r ../${file}.incoming ]; then
          cp -a $file ../${file}.incoming
        fi
      done
    )
    # Then switch to them all at once:
    /sbin/ldconfig -l lib64/*.incoming 2> /dev/null
    # Remove old versions of the glibc libraries. If you really don't want to
    # do this for some reason, create a file /etc/glibc-nowipe.
    if [ ! -r etc/glibc-nowipe ]; then
      ( cd lib64
        for INCOMING in incoming/*-* ; do
          LIBPREFIX=$(basename $INCOMING | cut -f 1 -d -)
          for LIBRARY in ${LIBPREFIX}-* ; do
            # Don't remove the library if it ends in .incoming:
            if [ "$(echo $LIBRARY | rev | cut -f 1 -d .)" = "gnimocni" ]; then
              continue
            fi
            # Don't remove symlinks:
            if [ -L $LIBRARY ]; then
              continue
            fi
            rm -f $LIBRARY
          done
        done
        # Remove stale versions of libcrypt from Slackware 14.2 or newer:
        rm -f libcrypt-{2.23,2.24,2.25,2.26,2.27,2.28,2.29,2.30,2.31,2.32,2.33,2.34,2.35,2.36,2.37}.so
      )
    fi
    # Finally, rename them and clean up:
    ( cd lib64
      for file in *.incoming ; do
        rm -f `basename $file .incoming`
        cp -a $file `basename $file .incoming`
        /sbin/ldconfig -l `basename $file .incoming` 2> /dev/null
        rm -f $file
      done
    )
  ) 9> run/lock/pkgtools/ldconfig.lock
else # no ldconfig? This is a broken situation, but we will do what we can:
  ( cd lib64/incoming
    for file in * ; do
      cp -a $file ..
    done
  )
fi
# Now, get rid of the temporary directory:
rm -rf lib64/incoming
# Done installing NPTL glibc libraries.

# Handle config files:
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/nscd.conf.new
config etc/profile.d/glibc.csh.new
config etc/profile.d/glibc.sh.new
# Clearly you already decided this issue.  :-)
rm -f etc/profile.d/glibc.csh.new
rm -f etc/profile.d/glibc.sh.new

# This block below *should* be dead code, but it's probably safer to leave it
# here as a fallback. It no longer has complete coverage of all the links
# that would be needed in /lib${LIBDIRSUFFIX}, but it covers enough that if
# we did fall back on this the machine would boot until it reached the boot
# time call to ldconfig, which would then take care of any missing links.
# In case there's no ldconfig, make the links manually:
if [ ! -x /sbin/ldconfig ]; then
( cd lib64 ; rm -rf libm.so.6 )
( cd lib64 ; ln -sf libm-2.40.so libm.so.6 )
( cd lib64 ; rm -rf libnss_files.so.2 )
( cd lib64 ; ln -sf libnss_files-2.40.so libnss_files.so.2 )
( cd lib64 ; rm -rf libresolv.so.2 )
( cd lib64 ; ln -sf libresolv-2.40.so libresolv.so.2 )
( cd lib64 ; rm -rf libutil.so.1 )
( cd lib64 ; ln -sf libutil-2.40.so libutil.so.1 )
( cd lib64 ; rm -rf libnss_compat.so.2 )
( cd lib64 ; ln -sf libnss_compat-2.40.so libnss_compat.so.2 )
( cd lib64 ; rm -rf libthread_db.so.1 )
( cd lib64 ; ln -sf libthread_db-1.0.so libthread_db.so.1 )
( cd lib64 ; rm -rf libnss_hesiod.so.2 )
( cd lib64 ; ln -sf libnss_hesiod-2.40.so libnss_hesiod.so.2 )
( cd lib64 ; rm -rf libanl.so.1 )
( cd lib64 ; ln -sf libanl-2.40.so libanl.so.1 )
( cd lib64 ; rm -rf libcrypt.so.1 )
( cd lib64 ; ln -sf libcrypt1-2.40.so libcrypt.so.1 )
( cd lib64 ; rm -rf libcrypt.so.2 )
( cd lib64 ; ln -sf libcrypt2-2.40.so libcrypt.so.2 )
( cd lib64 ; rm -rf libBrokenLocale.so.1 )
( cd lib64 ; ln -sf libBrokenLocale-2.40.so libBrokenLocale.so.1 )
( cd lib64 ; rm -rf ld-linux-loongarch-lp64d.so.1 )
( cd lib64 ; ln -sf ld-2.40.so ld-linux-loongarch-lp64d.so.1 )
( cd lib64 ; rm -rf libdl.so.2 )
( cd lib64 ; ln -sf libdl-2.40.so libdl.so.2 )
( cd lib64 ; rm -rf libnss_dns.so.2 )
( cd lib64 ; ln -sf libnss_dns-2.40.so libnss_dns.so.2 )
( cd lib64 ; rm -rf libpthread.so.0 )
( cd lib64 ; ln -sf libpthread-2.40.so libpthread.so.0 )
( cd lib64 ; rm -rf libc.so.6 )
( cd lib64 ; ln -sf libc-2.40.so libc.so.6 )
( cd lib64 ; rm -rf librt.so.1 )
( cd lib64 ; ln -sf librt-2.40.so librt.so.1 )
fi

# More links:
( cd bin ; rm -rf sln )
( cd bin ; ln -sf /sbin/sln sln )
( cd usr/bin ; rm -rf ld.so )
( cd usr/bin ; ln -sf ../../lib64/ld-linux-loongarch-lp64d.so.1 ld.so )
( cd usr/doc/libxcrypt-4.4.36 ; rm -rf README )
( cd usr/doc/libxcrypt-4.4.36 ; ln -sf README.md README )
( cd usr/doc/libxcrypt-4.4.36 ; rm -rf TODO )
( cd usr/doc/libxcrypt-4.4.36 ; ln -sf TODO.md TODO )
( cd usr/lib64 ; rm -rf libBrokenLocale.so )
( cd usr/lib64 ; ln -sf ../../lib64/libBrokenLocale.so.1 libBrokenLocale.so )
( cd usr/lib64 ; rm -rf libc_malloc_debug.so )
( cd usr/lib64 ; ln -sf ../../lib64/libc_malloc_debug.so.0 libc_malloc_debug.so )
( cd usr/lib64 ; rm -rf libcrypt.so )
( cd usr/lib64 ; ln -sf ../../lib64/libcrypt.so.2 libcrypt.so )
( cd usr/lib64 ; rm -rf libm.so )
( cd usr/lib64 ; ln -sf ../../lib64/libm.so.6 libm.so )
( cd usr/lib64 ; rm -rf libnss_compat.so )
( cd usr/lib64 ; ln -sf ../../lib64/libnss_compat.so.2 libnss_compat.so )
( cd usr/lib64 ; rm -rf libnss_db.so )
( cd usr/lib64 ; ln -sf ../../lib64/libnss_db.so.2 libnss_db.so )
( cd usr/lib64 ; rm -rf libnss_hesiod.so )
( cd usr/lib64 ; ln -sf ../../lib64/libnss_hesiod.so.2 libnss_hesiod.so )
( cd usr/lib64 ; rm -rf libresolv.so )
( cd usr/lib64 ; ln -sf ../../lib64/libresolv.so.2 libresolv.so )
( cd usr/lib64 ; rm -rf libthread_db.so )
( cd usr/lib64 ; ln -sf ../../lib64/libthread_db.so.1 libthread_db.so )
( cd usr/lib64 ; rm -rf libxcrypt.a )
( cd usr/lib64 ; ln -sf libcrypt.a libxcrypt.a )
( cd usr/lib64 ; rm -rf libxcrypt.so )
( cd usr/lib64 ; ln -sf ../../lib64/libcrypt.so.2 libxcrypt.so )
( cd usr/lib64/pkgconfig ; rm -rf libcrypt.pc )
( cd usr/lib64/pkgconfig ; ln -sf libxcrypt.pc libcrypt.pc )
